@@ -8,6 +8,11 @@ from nexustrader.base.oms import OrderManagementSystem
 from nexustrader.base.ws_client import WSClient
 from nexustrader.base.api_client import ApiClient
 from nexustrader.base.exchange import ExchangeManager
+from nexustrader.aggregation import (
+    KlineAggregator,
+    TimeKlineAggregator,
+    VolumeKlineAggregator,
+)
 from nexustrader.schema import (
     Order,
     BaseMarket,
@@ -15,6 +20,7 @@ from nexustrader.schema import (
     Balance,
     KlineList,
     Ticker,
+    Trade,
 )
 from nexustrader.constants import ExchangeType, AccountType
 from nexustrader.core.cache import AsyncCache
@@ -79,6 +85,9 @@ class PublicConnector(ABC):
         self._clock = clock
         self._task_manager = task_manager
 
+        # Aggregator management - key: symbol, value: list of aggregators
+        self._aggregators: Dict[str, List[KlineAggregator]] = {}
+
     @property
     def account_type(self):
         return self._account_type
@@ -133,10 +142,62 @@ class PublicConnector(ABC):
         pass
 
     @abstractmethod
-    async def subscribe_kline(self, symbol: str | List[str], interval: KlineInterval):
-        """Subscribe to the kline data"""
+    async def subscribe_kline(
+        self,
+        symbol: str | List[str],
+        interval: KlineInterval,
+    ):
+        """Subscribe to the kline data
+
+        Args:
+            symbol: Symbol(s) to subscribe to
+            interval: Kline interval
+            use_aggregator: If True, use TimeKlineAggregator instead of exchange native klines
+        """
         pass
 
+    async def subscribe_kline_aggregator(
+        self,
+        symbol: str,
+        interval: KlineInterval,
+    ):
+        """Subscribe to time-based kline data using TimeKlineAggregator
+
+        Args:
+            symbol: Symbol to subscribe to
+            interval: Kline interval
+        """
+        # Ensure trade subscription for the symbol
+        await self.subscribe_trade(symbol)
+
+        # Create and register time kline aggregator
+        aggregator = self._create_time_kline_aggregator(symbol, interval)
+        self._add_aggregator(symbol, aggregator)
+
+        self._log.info(
+            f"Time kline aggregator created for {symbol} with interval {interval}"
+        )
+
+    async def subscribe_volume_kline_aggregator(
+        self, symbol: str, volume_threshold: float
+    ):
+        """Subscribe to volume-based kline data using VolumeKlineAggregator
+
+        Args:
+            symbol: Symbol to subscribe to
+            volume_threshold: Volume threshold for creating new klines
+        """
+        # Ensure trade subscription for the symbol
+        await self.subscribe_trade(symbol)
+
+        # Create and register volume kline aggregator
+        aggregator = self._create_volume_kline_aggregator(symbol, volume_threshold)
+        self._add_aggregator(symbol, aggregator)
+
+        self._log.info(
+            f"Volume kline aggregator created for {symbol} with threshold {volume_threshold}"
+        )
+
     @abstractmethod
     async def subscribe_bookl2(self, symbol: str | List[str], level: BookLevel):
         """Subscribe to the bookl2 data"""
@@ -157,8 +218,56 @@ class PublicConnector(ABC):
         """Subscribe to the mark price data"""
         pass
 
+    def _create_time_kline_aggregator(
+        self,
+        symbol: str,
+        interval: KlineInterval,
+    ) -> TimeKlineAggregator:
+        """Create a time-based kline aggregator."""
+        return TimeKlineAggregator(
+            exchange=self._exchange_id,
+            symbol=symbol,
+            interval=interval,
+            msgbus=self._msgbus,
+            clock=self._clock,
+        )
+
+    def _create_volume_kline_aggregator(
+        self,
+        symbol: str,
+        volume_threshold: float,
+    ) -> VolumeKlineAggregator:
+        """Create a volume-based kline aggregator."""
+
+        return VolumeKlineAggregator(
+            exchange=self._exchange_id,
+            symbol=symbol,
+            msgbus=self._msgbus,
+            volume_threshold=volume_threshold,
+        )
+
+    def _add_aggregator(self, symbol: str, aggregator) -> None:
+        """Add an aggregator for a symbol."""
+        if symbol not in self._aggregators:
+            self._aggregators[symbol] = []
+        self._aggregators[symbol].append(aggregator)
+
+    def _handle_trade_for_aggregators(self, trade: Trade) -> None:
+        """Route trade data to all aggregators for this symbol."""
+        aggregators = self._aggregators.get(trade.symbol)
+        if aggregators:
+            for aggregator in aggregators:
+                aggregator.handle_trade(trade)
+
     async def disconnect(self):
         """Disconnect from the exchange"""
+        # Stop all aggregators
+        for aggregators in self._aggregators.values():
+            for aggregator in aggregators:
+                if hasattr(aggregator, "stop"):
+                    aggregator.stop()
+        self._aggregators.clear()
+
         self._ws_client.disconnect()  # not needed to await
         await self._api_client.close_session()
 
@@ -432,12 +541,12 @@ class MockLinearConnector:
                 exchange=self._exchange_id,
                 timestamp=self._clock.timestamp_ms(),
                 symbol=symbol,
+                status=OrderStatus.FAILED,
                 type=type,
                 side=side,
                 amount=amount,
                 price=float(price) if price else None,
                 time_in_force=time_in_force,
-                status=OrderStatus.FAILED,
                 filled=Decimal(0),
                 remaining=amount,
             )
