@@ -102,6 +102,7 @@ class KlineInterval(Enum):
     DAY_3 = "3d"
     WEEK_1 = "1w"
     MONTH_1 = "1M"
+    VOLUME = "volume"
 
     @property
     def seconds(self) -> int:
@@ -122,11 +123,20 @@ class KlineInterval(Enum):
             KlineInterval.DAY_3: 259200,
             KlineInterval.WEEK_1: 604800,
             KlineInterval.MONTH_1: 2592000,
+            KlineInterval.VOLUME: 0,
         }[self]
 
+    @property
+    def nanoseconds(self) -> int:
+        return self.seconds * 1_000_000_000
+
     @property
     def microseconds(self) -> int:
-        return self.seconds * 1000
+        return self.seconds * 1_000_000
+
+    @property
+    def milliseconds(self) -> int:
+        return self.seconds * 1_000
 
 
 class SubmitType(Enum):
@@ -335,6 +345,7 @@ class DataType(Enum):
     BOOKL2 = "bookl2"
     TRADE = "trade"
     KLINE = "kline"
+    VOLUME_KLINE = "volume_kline"
     MARK_PRICE = "mark_price"
     FUNDING_RATE = "funding_rate"
     INDEX_PRICE = "index_price"
