@@ -386,7 +386,7 @@ class BybitWsTrade(msgspec.Struct):
     # Symbol name
     s: str
     # Side of taker. Buy,Sell
-    S: str
+    S: BybitOrderSide
     # Trade size
     v: str
     # Trade price
