@@ -6,6 +6,16 @@ from nexustrader.exchange.hyperliquid.connector import (
 )
 from nexustrader.exchange.hyperliquid.oms import HyperLiquidOrderManagementSystem
 from nexustrader.exchange.hyperliquid.ems import HyperLiquidExecutionManagementSystem
+from nexustrader.exchange.hyperliquid.factory import HyperLiquidFactory
+
+# Auto-register factory on import
+try:
+    from nexustrader.exchange.registry import register_factory
+
+    register_factory(HyperLiquidFactory())
+except ImportError:
+    # Registry not available yet during bootstrap
+    pass
 
 __all__ = [
     "HyperLiquidExchangeManager",
@@ -14,4 +24,5 @@ __all__ = [
     "HyperLiquidPrivateConnector",
     "HyperLiquidOrderManagementSystem",
     "HyperLiquidExecutionManagementSystem",
+    "HyperLiquidFactory",
 ]
