@@ -3,6 +3,16 @@ from nexustrader.exchange.okx.exchange import OkxExchangeManager
 from nexustrader.exchange.okx.connector import OkxPublicConnector, OkxPrivateConnector
 from nexustrader.exchange.okx.ems import OkxExecutionManagementSystem
 from nexustrader.exchange.okx.oms import OkxOrderManagementSystem
+from nexustrader.exchange.okx.factory import OkxFactory
+
+# Auto-register factory on import
+try:
+    from nexustrader.exchange.registry import register_factory
+
+    register_factory(OkxFactory())
+except ImportError:
+    # Registry not available yet during bootstrap
+    pass
 
 __all__ = [
     "OkxAccountType",
@@ -11,4 +21,5 @@ __all__ = [
     "OkxPrivateConnector",
     "OkxExecutionManagementSystem",
     "OkxOrderManagementSystem",
+    "OkxFactory",
 ]
